==> apache-camel-quarkus-3.14.0-src.zip: camel-quarkus-3.14.0/integration-tests/openstack/src/test/java/org/apache/camel/quarkus/component/openstack/it/OpenstackCinderVolumeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.openstack.it;

import io.quarkus.test.common.WithTestResource;
import io.quarkus.test.junit.QuarkusTest;
import org.junit.jupiter.api.Test;

import static io.restassured.RestAssured.post;

@QuarkusTest
@WithTestResource(OpenStackTestResource.class)
class OpenstackCinderVolumeTest {

    @Test
    public void createShouldSucceed() {
        post("/openstack/cinder/volumes/createShouldSucceed").then().statusCode(204);
    }

    @Test
    public void getShouldSucceed() {
        post("/openstack/cinder/volumes/getShouldSucceed").then().statusCode(204);
    }

    @Test
    public void getAllShouldSucceed() {
        post("/openstack/cinder/volumes/getAllShouldSucceed").then().statusCode(204);
    }

    @Test
    public void getAllTypesShouldSucceed() {
        post("/openstack/cinder/volumes/getAllTypesShouldSucceed").then().statusCode(204);
    }

    @Test
    public void updateShouldSucceed() {
        post("/openstack/cinder/volumes/updateShouldSucceed").then().statusCode(204);
    }

    @Test
    public void deleteShouldSucceed() {
        post("/openstack/cinder/volumes/deleteShouldSucceed").then().statusCode(204);
    }
}

==> apache-camel-quarkus-3.27.1-src.zip: camel-quarkus-3.27.1/integration-tests/openstack/src/test/java/org/apache/camel/quarkus/component/openstack/it/OpenstackCinderVolumeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.openstack.it;

import io.quarkus.test.common.QuarkusTestResource;
import io.quarkus.test.junit.QuarkusTest;
import org.junit.jupiter.api.Test;

import static io.restassured.RestAssured.post;

@QuarkusTest
@QuarkusTestResource(OpenStackTestResource.class)
class OpenstackCinderVolumeTest {

    @Test
    public void createShouldSucceed() {
        post("/openstack/cinder/volumes/createShouldSucceed").then().statusCode(204);
    }

    @Test
    public void getShouldSucceed() {
        post("/openstack/cinder/volumes/getShouldSucceed").then().statusCode(204);
    }

    @Test
    public void getAllShouldSucceed() {
        post("/openstack/cinder/volumes/getAllShouldSucceed").then().statusCode(204);
    }

    @Test
    public void getAllTypesShouldSucceed() {
        post("/openstack/cinder/volumes/getAllTypesShouldSucceed").then().statusCode(204);
    }

    @Test
    public void updateShouldSucceed() {
        post("/openstack/cinder/volumes/updateShouldSucceed").then().statusCode(204);
    }

    @Test
    public void deleteShouldSucceed() {
        post("/openstack/cinder/volumes/deleteShouldSucceed").then().statusCode(204);
    }
}
